@@ -23,7 +23,7 @@ __copyright__ = '(C) 2014, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 import os
 from qgis.PyQt.QtCore import QCoreApplication
@@ -52,7 +52,7 @@ class Grass7AlgorithmProvider(QgsProcessingProvider):
         ProcessingConfig.settingIcons[self.name()] = self.icon()
         ProcessingConfig.addSetting(Setting(self.name(), 'ACTIVATE_GRASS7',
                                             self.tr('Activate'), True))
-        if isWindows() or isMac():
+        if isMac():
             ProcessingConfig.addSetting(Setting(
                 self.name(),
                 Grass7Utils.GRASS_FOLDER, self.tr('GRASS7 folder'),
@@ -84,7 +84,7 @@ class Grass7AlgorithmProvider(QgsProcessingProvider):
 
     def unload(self):
         ProcessingConfig.removeSetting('ACTIVATE_GRASS7')
-        if isWindows() or isMac():
+        if isMac():
             ProcessingConfig.removeSetting(Grass7Utils.GRASS_FOLDER)
         ProcessingConfig.removeSetting(Grass7Utils.GRASS_LOG_COMMANDS)
         ProcessingConfig.removeSetting(Grass7Utils.GRASS_LOG_CONSOLE)
@@ -128,12 +128,18 @@ class Grass7AlgorithmProvider(QgsProcessingProvider):
     def id(self):
         return 'grass7'
 
+    def helpId(self):
+        return 'grass7'
+
     def icon(self):
         return QgsApplication.getThemeIcon("/providerGrass.svg")
 
     def svgIconPath(self):
         return QgsApplication.iconPath("/providerGrass.svg")
 
+    def defaultVectorFileExtension(self, hasGeometry=True):
+        return 'gpkg'
+
     def supportsNonFileBasedOutput(self):
         """
         GRASS7 Provider doesn't support non file based outputs
@@ -151,7 +157,7 @@ class Grass7AlgorithmProvider(QgsProcessingProvider):
         return Grass7Utils.getSupportedOutputRasterExtensions()
 
     def canBeActivated(self):
-        return not bool(Grass7Utils.checkGrass7IsInstalled())
+        return not bool(Grass7Utils.checkGrassIsInstalled())
 
     def tr(self, string, context=''):
         if context == '':
