@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive323
 
-__revision__ = '1edf372fb80f2a35c77b128dc143c0f3c97cd8f3'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 import os
 
@@ -36,7 +36,6 @@ from qgis.core import (QgsApplication,
                        QgsProcessingException,
                        QgsProcessingParameterDistance,
                        QgsProcessingParameterFeatureSource,
-                       QgsProcessingParameterNumber,
                        QgsProcessingParameterFeatureSink)
 
 from qgis.PyQt.QtCore import QVariant
@@ -75,7 +74,7 @@ class PoleOfInaccessibility(QgisAlgorithm):
         self.addParameter(QgsProcessingParameterFeatureSource(self.INPUT, self.tr('Input layer'),
                                                               [QgsProcessing.TypeVectorPolygon]))
         self.addParameter(QgsProcessingParameterDistance(self.TOLERANCE,
-                                                         self.tr('Tolerance (layer units)'),
+                                                         self.tr('Tolerance'),
                                                          parentParameterName=self.INPUT,
                                                          defaultValue=1.0, minValue=0.0))
 
