@@ -23,7 +23,7 @@ __copyright__ = '(C) 2014, Arnaud Morvan'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 import os
 from collections import OrderedDict
@@ -36,6 +36,7 @@ from qgis.PyQt.QtCore import (
     QVariant,
     Qt,
     pyqtSlot,
+    QCoreApplication
 )
 from qgis.PyQt.QtWidgets import (
     QComboBox,
@@ -45,6 +46,8 @@ from qgis.PyQt.QtWidgets import (
     QMessageBox,
     QSpinBox,
     QStyledItemDelegate,
+    QWidget,
+    QVBoxLayout
 )
 
 from qgis.core import (
@@ -58,8 +61,9 @@ from qgis.core import (
 )
 from qgis.gui import QgsFieldExpressionWidget
 
-from processing.gui.wrappers import WidgetWrapper, DIALOG_STANDARD, DIALOG_MODELER
+from processing.gui.wrappers import WidgetWrapper, DIALOG_STANDARD, DIALOG_MODELER, DIALOG_BATCH
 from processing.tools import dataobjects
+from processing.algs.qgis.FieldsMapper import FieldsMapper
 
 
 pluginPath = os.path.dirname(__file__)
@@ -141,7 +145,10 @@ class FieldsMappingModel(QAbstractTableModel):
     def rowCount(self, parent=QModelIndex()):
         if parent.isValid():
             return 0
-        return self._mapping.__len__()
+        try:
+            return len(self._mapping)
+        except TypeError:
+            return 0
 
     def headerData(self, section, orientation, role=Qt.DisplayRole):
         if role == Qt.DisplayRole:
@@ -235,7 +242,7 @@ class FieldTypeDelegate(QStyledItemDelegate):
 
     def createEditor(self, parent, option, index):
         editor = QComboBox(parent)
-        for key, text in list(FieldsMappingModel.fieldTypes.items()):
+        for key, text in FieldsMappingModel.fieldTypes.items():
             editor.addItem(text, key)
         return editor
 
@@ -474,16 +481,41 @@ class FieldsMappingWidgetWrapper(WidgetWrapper):
         super(FieldsMappingWidgetWrapper, self).__init__(*args, **kwargs)
         self._layer = None
 
+    def createPanel(self):
+        return FieldsMappingPanel()
+
     def createWidget(self):
-        panel = FieldsMappingPanel()
-        panel.dialogType = self.dialogType
-        return panel
+        self.panel = self.createPanel()
+        self.panel.dialogType = self.dialogType
+
+        if self.dialogType == DIALOG_MODELER:
+            self.combobox = QComboBox()
+            self.combobox.addItem(QCoreApplication.translate('Processing', '[Preconfigure]'), None)
+            fieldsMappingInputs = self.dialog.getAvailableValuesOfType(FieldsMapper.ParameterFieldsMapping)
+            for input in fieldsMappingInputs:
+                self.combobox.addItem(self.dialog.resolveValueDescription(input), input)
+
+            def updatePanelEnabledState():
+                if self.combobox.currentData() is None:
+                    self.panel.setEnabled(True)
+                else:
+                    self.panel.setEnabled(False)
+
+            self.combobox.currentIndexChanged.connect(updatePanelEnabledState)
+
+            widget = QWidget()
+            widget.setLayout(QVBoxLayout())
+            widget.layout().addWidget(self.combobox)
+            widget.layout().addWidget(self.panel)
+            return widget
+        else:
+            return self.panel
 
     def postInitialize(self, wrappers):
         for wrapper in wrappers:
-            if wrapper.param.name() == self.param.parentLayerParameter():
-                if wrapper.value():
-                    self.setLayer(wrapper.value())
+            if wrapper.parameterDefinition().name() == self.parameterDefinition().parentLayerParameter():
+                if wrapper.parameterValue():
+                    self.setLayer(wrapper.parameterValue())
                 wrapper.widgetValueHasChanged.connect(self.parentLayerChanged)
                 break
 
@@ -508,10 +540,16 @@ class FieldsMappingWidgetWrapper(WidgetWrapper):
         if not isinstance(layer, QgsVectorLayer):
             layer = None
         self._layer = layer
-        self.widget.setLayer(self._layer)
+        self.panel.setLayer(self._layer)
 
     def setValue(self, value):
-        self.widget.setValue(value)
+        self.panel.setValue(value)
 
     def value(self):
-        return self.widget.value()
+        if self.dialogType == DIALOG_MODELER:
+            if self.combobox.currentData() is None:
+                return self.panel.value()
+            else:
+                return self.comboValue(combobox=self.combobox)
+        else:
+            return self.panel.value()
